Events
======

.. _events:

Introduction
------------
The event detection module analyses a body of text to identify events that have taken place. This is
useful for identifying mentions of personal experience or story mining.

Usage
-----

To use the module:

.. code-block:: console

    >>> import coast_core
    >>> coast_core.events.function(to_use)

or:

.. code-block:: console

    >>> from coast_core import events
    >>> events.function(to_use)

Functions
---------
.. automodule:: coast_core.events
    :members:
    :undoc-members:
    :show-inheritance:
